@@ -1,7 +1,10 @@
 use cqrs_es::{Aggregate, CqrsFramework, Query};
+use persist_es::{PersistedEventStore, PersistedSnapshotStore};
+use std::sync::Arc;
 
-use crate::snapshot_store::PostgresSnapshotStore;
-use crate::{PostgresCqrs, PostgresSnapshotCqrs, PostgresStore};
+use crate::event_repository::PostgresEventRepository;
+use crate::snapshot_repository::PostgresSnapshotRepository;
+use crate::{PostgresCqrs, PostgresSnapshotCqrs};
 use sqlx::postgres::PgPoolOptions;
 use sqlx::{Pool, Postgres};
 
@@ -18,23 +21,26 @@ pub async fn default_postgress_pool(connection_string: &str) -> Pool<Postgres> {
 /// and queries.
 pub fn postgres_cqrs<A>(
     pool: Pool<Postgres>,
-    query_processor: Vec<Box<dyn Query<A>>>,
+    query_processor: Vec<Arc<dyn Query<A>>>,
 ) -> PostgresCqrs<A>
 where
     A: Aggregate,
 {
-    let store = PostgresStore::new(pool);
+    let repo = PostgresEventRepository::new(pool);
+    let store = PersistedEventStore::new(repo);
     CqrsFramework::new(store, query_processor)
 }
 
 /// A convenience function for creating a CqrsFramework using a snapshot store.
 pub fn postgres_snapshot_cqrs<A>(
     pool: Pool<Postgres>,
-    query_processor: Vec<Box<dyn Query<A>>>,
+    query_processor: Vec<Arc<dyn Query<A>>>,
 ) -> PostgresSnapshotCqrs<A>
 where
     A: Aggregate,
 {
-    let store = PostgresSnapshotStore::new(pool);
+    let repo = PostgresEventRepository::new(pool.clone());
+    let snapshot_repo = PostgresSnapshotRepository::new(pool);
+    let store = PersistedSnapshotStore::new(snapshot_repo, repo);
     CqrsFramework::new(store, query_processor)
 }
