@@ -1,19 +1,23 @@
 #[cfg(test)]
 mod tests {
     use std::collections::HashMap;
+    use std::sync::Arc;
 
     use cqrs_es::{Aggregate, AggregateError, DomainEvent, EventEnvelope, EventStore, View};
+    use persist_es::{
+        GenericQuery, PersistedEventRepository, PersistedEventStore,
+        PersistedSnapshotEventRepository, PersistedSnapshotStore, SnapshotStoreAggregateContext,
+    };
     use serde::{Deserialize, Serialize};
     use serde_json::{Map, Value};
     use sqlx::{Pool, Postgres};
     use static_assertions::assert_impl_all;
 
-    use crate::event_repository::EventRepository;
-    use crate::snapshot_repository::SnapshotRepository;
-    use crate::{default_postgress_pool, GenericQuery};
-    use crate::{
-        postgres_cqrs, PostgresSnapshotStore, PostgresSnapshotStoreAggregateContext, PostgresStore,
-    };
+    use crate::default_postgress_pool;
+    use crate::event_repository::PostgresEventRepository;
+    use crate::postgres_cqrs;
+    use crate::query_repository::PostgresViewRepository;
+    use crate::snapshot_repository::PostgresSnapshotRepository;
 
     #[derive(Debug, Serialize, Deserialize, PartialEq)]
     pub struct TestAggregate {
@@ -85,7 +89,8 @@ mod tests {
 
     pub enum TestCommand {}
 
-    type TestQueryRepository = GenericQuery<TestView, TestAggregate>;
+    type TestQueryRepository =
+        GenericQuery<PostgresViewRepository<TestView, TestAggregate>, TestView, TestAggregate>;
 
     #[derive(Debug, Default, Serialize, Deserialize)]
     struct TestView {
@@ -98,16 +103,31 @@ mod tests {
         }
     }
 
-    assert_impl_all!(rdbmsstore; PostgresStore::<TestAggregate>, EventStore::<TestAggregate>);
+    assert_impl_all!(rdbmsstore; PersistedEventStore::<PostgresEventRepository<TestAggregate>, TestAggregate>, EventStore::<TestAggregate>);
 
     const TEST_CONNECTION_STRING: &str = "postgresql://test_user:test_pass@localhost:5432/test";
 
-    async fn test_store(pool: Pool<Postgres>) -> PostgresStore<TestAggregate> {
-        PostgresStore::<TestAggregate>::new(pool)
+    async fn test_store(
+        pool: Pool<Postgres>,
+    ) -> PersistedEventStore<PostgresEventRepository<TestAggregate>, TestAggregate> {
+        let repo = PostgresEventRepository::new(pool);
+        PersistedEventStore::<PostgresEventRepository<TestAggregate>, TestAggregate>::new(repo)
     }
 
-    async fn test_snapshot_store(pool: Pool<Postgres>) -> PostgresSnapshotStore<TestAggregate> {
-        PostgresSnapshotStore::<TestAggregate>::new(pool)
+    async fn test_snapshot_store(
+        pool: Pool<Postgres>,
+    ) -> PersistedSnapshotStore<
+        PostgresEventRepository<TestAggregate>,
+        PostgresSnapshotRepository<TestAggregate>,
+        TestAggregate,
+    > {
+        let repo = PostgresEventRepository::new(pool.clone());
+        let snapshot_repo = PostgresSnapshotRepository::new(pool);
+        PersistedSnapshotStore::<
+            PostgresEventRepository<TestAggregate>,
+            PostgresSnapshotRepository<TestAggregate>,
+            TestAggregate,
+        >::new(snapshot_repo, repo)
     }
 
     fn test_metadata() -> HashMap<String, String> {
@@ -120,41 +140,26 @@ mod tests {
     #[tokio::test]
     async fn test_valid_cqrs_framework() {
         let pool = default_postgress_pool(TEST_CONNECTION_STRING).await;
-        let query = TestQueryRepository::new("test_query", pool.clone());
-        let _ps = postgres_cqrs(pool, vec![Box::new(query)]);
+        let repo =
+            PostgresViewRepository::<TestView, TestAggregate>::new("test_query", pool.clone());
+        let query = TestQueryRepository::new(repo);
+        let _ps = postgres_cqrs(pool, vec![Arc::new(query)]);
     }
 
-    #[tokio::test]
-    async fn query() {
-        let pool = default_postgress_pool(TEST_CONNECTION_STRING).await;
-        let query = TestQueryRepository::new("test_query", pool.clone());
-        let id = uuid::Uuid::new_v4().to_string();
-        query
-            .apply_events(
-                &id,
-                &vec![
-                    EventEnvelope {
-                        aggregate_id: id.clone(),
-                        sequence: 1,
-                        aggregate_type: TestAggregate::aggregate_type().to_string(),
-                        payload: TestEvent::Created(Created { id: id.clone() }),
-                        metadata: Default::default(),
-                    },
-                    EventEnvelope {
-                        aggregate_id: id.clone(),
-                        sequence: 2,
-                        aggregate_type: TestAggregate::aggregate_type().to_string(),
-                        payload: TestEvent::Tested(Tested {
-                            test_name: "a test was run".to_string(),
-                        }),
-                        metadata: Default::default(),
-                    },
-                ],
-            )
-            .await
-            .unwrap();
-        let result = query.load(id).await.unwrap();
-        assert_eq!(2, result.events.len())
+    fn test_event_envelope(
+        id: &str,
+        sequence: usize,
+        payload: TestEvent,
+    ) -> EventEnvelope<TestAggregate> {
+        EventEnvelope {
+            aggregate_id: id.to_string(),
+            sequence,
+            aggregate_type: TestAggregate::aggregate_type().to_string(),
+            event_type: payload.event_type().to_string(),
+            event_version: payload.event_version().to_string(),
+            payload,
+            metadata: Default::default(),
+        }
     }
 
     #[tokio::test]
@@ -276,28 +281,21 @@ mod tests {
     async fn event_repositories() {
         let pool = default_postgress_pool(TEST_CONNECTION_STRING).await;
         let id = uuid::Uuid::new_v4().to_string();
-        let event_repo: EventRepository<TestAggregate> = EventRepository::new(pool.clone());
+        let event_repo: PostgresEventRepository<TestAggregate> =
+            PostgresEventRepository::new(pool.clone());
         let events = event_repo.get_events(&id).await.unwrap();
         assert!(events.is_empty());
 
         event_repo
             .insert_events(vec![
-                EventEnvelope {
-                    aggregate_id: id.clone(),
-                    sequence: 1,
-                    aggregate_type: TestAggregate::aggregate_type().to_string(),
-                    payload: TestEvent::Created(Created { id: id.clone() }),
-                    metadata: Default::default(),
-                },
-                EventEnvelope {
-                    aggregate_id: id.clone(),
-                    sequence: 2,
-                    aggregate_type: TestAggregate::aggregate_type().to_string(),
-                    payload: TestEvent::Tested(Tested {
+                test_event_envelope(&id, 1, TestEvent::Created(Created { id: id.clone() })),
+                test_event_envelope(
+                    &id,
+                    2,
+                    TestEvent::Tested(Tested {
                         test_name: "a test was run".to_string(),
                     }),
-                    metadata: Default::default(),
-                },
+                ),
             ])
             .await
             .unwrap();
@@ -307,24 +305,20 @@ mod tests {
 
         event_repo
             .insert_events(vec![
-                EventEnvelope {
-                    aggregate_id: id.clone(),
-                    sequence: 3,
-                    aggregate_type: TestAggregate::aggregate_type().to_string(),
-                    payload: TestEvent::SomethingElse(SomethingElse {
+                test_event_envelope(
+                    &id,
+                    3,
+                    TestEvent::SomethingElse(SomethingElse {
                         description: "this should not persist".to_string(),
                     }),
-                    metadata: Default::default(),
-                },
-                EventEnvelope {
-                    aggregate_id: id.clone(),
-                    sequence: 2,
-                    aggregate_type: TestAggregate::aggregate_type().to_string(),
-                    payload: TestEvent::SomethingElse(SomethingElse {
+                ),
+                test_event_envelope(
+                    &id,
+                    2,
+                    TestEvent::SomethingElse(SomethingElse {
                         description: "bad sequence number".to_string(),
                     }),
-                    metadata: Default::default(),
-                },
+                ),
             ])
             .await
             .unwrap_err();
@@ -336,7 +330,8 @@ mod tests {
     async fn snapshot_repositories() {
         let pool = default_postgress_pool(TEST_CONNECTION_STRING).await;
         let id = uuid::Uuid::new_v4().to_string();
-        let repo: SnapshotRepository<TestAggregate> = SnapshotRepository::new(pool.clone());
+        let repo: PostgresSnapshotRepository<TestAggregate> =
+            PostgresSnapshotRepository::new(pool.clone());
         let snapshot = repo.get_snapshot(&id).await.unwrap();
         assert_eq!(None, snapshot);
 
@@ -431,8 +426,8 @@ mod tests {
         current_sequence: usize,
         current_snapshot: usize,
         aggregate: A,
-    ) -> PostgresSnapshotStoreAggregateContext<A> {
-        PostgresSnapshotStoreAggregateContext {
+    ) -> SnapshotStoreAggregateContext<A> {
+        SnapshotStoreAggregateContext {
             aggregate_id,
             aggregate,
             current_sequence,
